Class: Aws::Invoicing::Types::CreateProcurementPortalPreferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::CreateProcurementPortalPreferenceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:procurement_portal_shared_secret, :contacts]
Instance Attribute Summary collapse
-
#buyer_domain ⇒ String
The domain identifier for the buyer in the procurement portal.
-
#buyer_identifier ⇒ String
The unique identifier for the buyer in the procurement portal.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
-
#contacts ⇒ Array<Types::Contact>
List of contact information for portal administrators and technical contacts responsible for the e-invoice integration.
-
#einvoice_delivery_enabled ⇒ Boolean
Indicates whether e-invoice delivery is enabled for this procurement portal preference.
-
#einvoice_delivery_preference ⇒ Types::EinvoiceDeliveryPreference
Specifies the e-invoice delivery configuration including document types, attachment types, and customization settings for the portal.
-
#procurement_portal_instance_endpoint ⇒ String
The endpoint URL where e-invoices will be delivered to the procurement portal.
-
#procurement_portal_name ⇒ String
The name of the procurement portal.
-
#procurement_portal_shared_secret ⇒ String
The shared secret or authentication credential used to establish secure communication with the procurement portal.
-
#purchase_order_retrieval_enabled ⇒ Boolean
Indicates whether purchase order retrieval is enabled for this procurement portal preference.
-
#resource_tags ⇒ Array<Types::ResourceTag>
The tags to apply to this procurement portal preference resource.
-
#selector ⇒ Types::ProcurementPortalPreferenceSelector
Specifies criteria for selecting which invoices should be processed using a particular procurement portal preference.
-
#supplier_domain ⇒ String
The domain identifier for the supplier in the procurement portal.
-
#supplier_identifier ⇒ String
The unique identifier for the supplier in the procurement portal.
-
#test_env_preference ⇒ Types::TestEnvPreferenceInput
Configuration settings for the test environment of the procurement portal.
Instance Attribute Details
#buyer_domain ⇒ String
The domain identifier for the buyer in the procurement portal.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#buyer_identifier ⇒ String
The unique identifier for the buyer in the procurement portal.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#contacts ⇒ Array<Types::Contact>
List of contact information for portal administrators and technical contacts responsible for the e-invoice integration.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#einvoice_delivery_enabled ⇒ Boolean
Indicates whether e-invoice delivery is enabled for this procurement portal preference. Set to true to enable e-invoice delivery, false to disable.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#einvoice_delivery_preference ⇒ Types::EinvoiceDeliveryPreference
Specifies the e-invoice delivery configuration including document types, attachment types, and customization settings for the portal.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#procurement_portal_instance_endpoint ⇒ String
The endpoint URL where e-invoices will be delivered to the procurement portal. Must be a valid HTTPS URL.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#procurement_portal_name ⇒ String
The name of the procurement portal.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#procurement_portal_shared_secret ⇒ String
The shared secret or authentication credential used to establish secure communication with the procurement portal. This value must be encrypted at rest.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#purchase_order_retrieval_enabled ⇒ Boolean
Indicates whether purchase order retrieval is enabled for this procurement portal preference. Set to true to enable PO retrieval, false to disable.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
The tags to apply to this procurement portal preference resource. Each tag consists of a key and an optional value.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#selector ⇒ Types::ProcurementPortalPreferenceSelector
Specifies criteria for selecting which invoices should be processed using a particular procurement portal preference.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#supplier_domain ⇒ String
The domain identifier for the supplier in the procurement portal.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#supplier_identifier ⇒ String
The unique identifier for the supplier in the procurement portal.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#test_env_preference ⇒ Types::TestEnvPreferenceInput
Configuration settings for the test environment of the procurement portal. Includes test credentials and endpoints that are used for validation before production deployment.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/aws-sdk-invoicing/types.rb', line 295 class CreateProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :resource_tags, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |