Class: Aws::Invoicing::Types::DeleteProcurementPortalPreferenceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-invoicing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


428
429
430
431
432
433
# File 'lib/aws-sdk-invoicing/types.rb', line 428

class DeleteProcurementPortalPreferenceRequest < Struct.new(
  :procurement_portal_preference_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#procurement_portal_preference_arnString

The Amazon Resource Name (ARN) of the procurement portal preference to delete.

Returns:

  • (String)


428
429
430
431
432
433
# File 'lib/aws-sdk-invoicing/types.rb', line 428

class DeleteProcurementPortalPreferenceRequest < Struct.new(
  :procurement_portal_preference_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end