Class: Aws::Invoicing::Types::Entity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-invoicing/types.rb

Overview

The organization name providing Amazon Web Services services.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_entityString

Helps you identify whether your invoices are for Amazon Web Services Marketplace or for purchases of other Amazon Web Services services.

Returns:

  • (String)


520
521
522
523
524
525
# File 'lib/aws-sdk-invoicing/types.rb', line 520

class Entity < Struct.new(
  :invoicing_entity,
  :billing_entity)
  SENSITIVE = []
  include Aws::Structure
end

#invoicing_entityString

The name of the entity that issues the Amazon Web Services invoice.

Returns:

  • (String)


520
521
522
523
524
525
# File 'lib/aws-sdk-invoicing/types.rb', line 520

class Entity < Struct.new(
  :invoicing_entity,
  :billing_entity)
  SENSITIVE = []
  include Aws::Structure
end