Class: Aws::Invoicing::Types::GetInvoicePDFResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::GetInvoicePDFResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invoice_pdf ⇒ Types::InvoicePDF
The invoice document and supplemental documents associated with the invoice.
Instance Attribute Details
#invoice_pdf ⇒ Types::InvoicePDF
The invoice document and supplemental documents associated with the invoice.
638 639 640 641 642 |
# File 'lib/aws-sdk-invoicing/types.rb', line 638 class GetInvoicePDFResponse < Struct.new( :invoice_pdf) SENSITIVE = [] include Aws::Structure end |