Class: Aws::Invoicing::Types::GetInvoiceUnitResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::GetInvoiceUnitResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The assigned description for an invoice unit.
-
#invoice_receiver ⇒ String
The Amazon Web Services account ID chosen to be the receiver of an invoice unit.
-
#invoice_unit_arn ⇒ String
The ARN to identify an invoice unit.
-
#last_modified ⇒ Time
The most recent date the invoice unit response was updated.
-
#name ⇒ String
The unique name of the invoice unit that is shown on the generated invoice.
-
#rule ⇒ Types::InvoiceUnitRule
This is used to categorize the invoice unit.
-
#tax_inheritance_disabled ⇒ Boolean
Whether the invoice unit based tax inheritance is/ should be enabled or disabled.
Instance Attribute Details
#description ⇒ String
The assigned description for an invoice unit.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/aws-sdk-invoicing/types.rb', line 702 class GetInvoiceUnitResponse < Struct.new( :invoice_unit_arn, :invoice_receiver, :name, :description, :tax_inheritance_disabled, :rule, :last_modified) SENSITIVE = [] include Aws::Structure end |
#invoice_receiver ⇒ String
The Amazon Web Services account ID chosen to be the receiver of an invoice unit. All invoices generated for that invoice unit will be sent to this account ID.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/aws-sdk-invoicing/types.rb', line 702 class GetInvoiceUnitResponse < Struct.new( :invoice_unit_arn, :invoice_receiver, :name, :description, :tax_inheritance_disabled, :rule, :last_modified) SENSITIVE = [] include Aws::Structure end |
#invoice_unit_arn ⇒ String
The ARN to identify an invoice unit. This information can’t be modified or deleted.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/aws-sdk-invoicing/types.rb', line 702 class GetInvoiceUnitResponse < Struct.new( :invoice_unit_arn, :invoice_receiver, :name, :description, :tax_inheritance_disabled, :rule, :last_modified) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The most recent date the invoice unit response was updated.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/aws-sdk-invoicing/types.rb', line 702 class GetInvoiceUnitResponse < Struct.new( :invoice_unit_arn, :invoice_receiver, :name, :description, :tax_inheritance_disabled, :rule, :last_modified) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name of the invoice unit that is shown on the generated invoice.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/aws-sdk-invoicing/types.rb', line 702 class GetInvoiceUnitResponse < Struct.new( :invoice_unit_arn, :invoice_receiver, :name, :description, :tax_inheritance_disabled, :rule, :last_modified) SENSITIVE = [] include Aws::Structure end |
#rule ⇒ Types::InvoiceUnitRule
This is used to categorize the invoice unit. Values are Amazon Web Services account IDs. Currently, the only supported rule is ‘LINKED_ACCOUNT`.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/aws-sdk-invoicing/types.rb', line 702 class GetInvoiceUnitResponse < Struct.new( :invoice_unit_arn, :invoice_receiver, :name, :description, :tax_inheritance_disabled, :rule, :last_modified) SENSITIVE = [] include Aws::Structure end |
#tax_inheritance_disabled ⇒ Boolean
Whether the invoice unit based tax inheritance is/ should be enabled or disabled.
702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/aws-sdk-invoicing/types.rb', line 702 class GetInvoiceUnitResponse < Struct.new( :invoice_unit_arn, :invoice_receiver, :name, :description, :tax_inheritance_disabled, :rule, :last_modified) SENSITIVE = [] include Aws::Structure end |