Class: Aws::Invoicing::Types::InternalServerException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-invoicing/types.rb

Overview

The processing request failed because of an unknown error, exception, or failure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


753
754
755
756
757
758
# File 'lib/aws-sdk-invoicing/types.rb', line 753

class InternalServerException < Struct.new(
  :retry_after_seconds,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#retry_after_secondsInteger

The processing request failed because of an unknown error, exception, or failure.

Returns:

  • (Integer)


753
754
755
756
757
758
# File 'lib/aws-sdk-invoicing/types.rb', line 753

class InternalServerException < Struct.new(
  :retry_after_seconds,
  :message)
  SENSITIVE = []
  include Aws::Structure
end