Class: Aws::Invoicing::Types::InvoiceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::InvoiceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
The invoice that the API retrieved.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID.
-
#base_currency_amount ⇒ Types::InvoiceCurrencyAmount
The summary with the product and service currency.
-
#bill_source_accounts ⇒ Array<String>
The list of Amazon Web Services account IDs that are the bill source of the invoice.
-
#bill_source_accounts_total_count ⇒ Integer
The total number of accounts that are the bill source of the invoice.
-
#bill_type ⇒ String
The type of the bill.
-
#billing_period ⇒ Types::BillingPeriod
The billing period of the invoice-related document.
-
#commercial_invoice_id ⇒ String
The commercial invoice ID.
-
#due_date ⇒ Time
The invoice due date.
-
#einvoice_delivery_status ⇒ String
The e-invoice delivery status.
-
#entity ⇒ Types::Entity
The organization name providing Amazon Web Services services.
-
#invoice_frequency ⇒ String
The frequency of the invoice.
-
#invoice_id ⇒ String
The invoice ID.
-
#invoice_type ⇒ String
The type of invoice.
-
#issued_date ⇒ Time
The issued date of the invoice.
-
#original_invoice_id ⇒ String
The initial or original invoice ID.
-
#payment_currency_amount ⇒ Types::InvoiceCurrencyAmount
The summary with the customer configured currency.
-
#purchase_order_number ⇒ String
The purchase order number associated to the invoice.
-
#receiver_role ⇒ String
The role of the invoice receiver.
-
#tax_authority_status ⇒ String
The current status of an invoice as reported to the tax authority.
-
#tax_currency_amount ⇒ Types::InvoiceCurrencyAmount
The summary with the tax currency.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#base_currency_amount ⇒ Types::InvoiceCurrencyAmount
The summary with the product and service currency.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#bill_source_accounts ⇒ Array<String>
The list of Amazon Web Services account IDs that are the bill source of the invoice. Currently, only a single bill source account is returned.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#bill_source_accounts_total_count ⇒ Integer
The total number of accounts that are the bill source of the invoice.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#bill_type ⇒ String
The type of the bill.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#billing_period ⇒ Types::BillingPeriod
The billing period of the invoice-related document.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#commercial_invoice_id ⇒ String
The commercial invoice ID. This is only applicable for tax invoices and identifies the associated commercial invoice.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#due_date ⇒ Time
The invoice due date.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#einvoice_delivery_status ⇒ String
The e-invoice delivery status.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#entity ⇒ Types::Entity
The organization name providing Amazon Web Services services.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#invoice_frequency ⇒ String
The frequency of the invoice.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#invoice_id ⇒ String
The invoice ID.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#invoice_type ⇒ String
The type of invoice.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#issued_date ⇒ Time
The issued date of the invoice.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#original_invoice_id ⇒ String
The initial or original invoice ID.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#payment_currency_amount ⇒ Types::InvoiceCurrencyAmount
The summary with the customer configured currency.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#purchase_order_number ⇒ String
The purchase order number associated to the invoice.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#receiver_role ⇒ String
The role of the invoice receiver.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#tax_authority_status ⇒ String
The current status of an invoice as reported to the tax authority. This captures scenarios where an invoice may be cancelled after issuance.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |
#tax_currency_amount ⇒ Types::InvoiceCurrencyAmount
The summary with the tax currency.
1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1010 class InvoiceSummary < Struct.new( :account_id, :invoice_id, :issued_date, :due_date, :bill_source_accounts, :bill_source_accounts_total_count, :receiver_role, :entity, :billing_period, :invoice_frequency, :bill_type, :invoice_type, :commercial_invoice_id, :original_invoice_id, :purchase_order_number, :einvoice_delivery_status, :tax_authority_status, :base_currency_amount, :tax_currency_amount, :payment_currency_amount) SENSITIVE = [] include Aws::Structure end |