Class: Aws::Invoicing::Types::InvoiceUnit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-invoicing/types.rb

Overview

An invoice unit is a set of mutually exclusive accounts that correspond to your business entity. Invoice units allow you separate Amazon Web Services account costs and configures your invoice for each business entity going forward.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The assigned description for an invoice unit. This information can’t be modified or deleted.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-invoicing/types.rb', line 1076

class InvoiceUnit < Struct.new(
  :invoice_unit_arn,
  :invoice_receiver,
  :name,
  :description,
  :tax_inheritance_disabled,
  :rule,
  :last_modified)
  SENSITIVE = []
  include Aws::Structure
end

#invoice_receiverString

The account that receives invoices related to the invoice unit.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-invoicing/types.rb', line 1076

class InvoiceUnit < Struct.new(
  :invoice_unit_arn,
  :invoice_receiver,
  :name,
  :description,
  :tax_inheritance_disabled,
  :rule,
  :last_modified)
  SENSITIVE = []
  include Aws::Structure
end

#invoice_unit_arnString

ARN to identify an invoice unit. This information can’t be modified or deleted.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-invoicing/types.rb', line 1076

class InvoiceUnit < Struct.new(
  :invoice_unit_arn,
  :invoice_receiver,
  :name,
  :description,
  :tax_inheritance_disabled,
  :rule,
  :last_modified)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The last time the invoice unit was updated. This is important to determine the version of invoice unit configuration used to create the invoices. Any invoice created after this modified time will use this invoice unit configuration.

Returns:

  • (Time)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-invoicing/types.rb', line 1076

class InvoiceUnit < Struct.new(
  :invoice_unit_arn,
  :invoice_receiver,
  :name,
  :description,
  :tax_inheritance_disabled,
  :rule,
  :last_modified)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A unique name that is distinctive within your Amazon Web Services.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-invoicing/types.rb', line 1076

class InvoiceUnit < Struct.new(
  :invoice_unit_arn,
  :invoice_receiver,
  :name,
  :description,
  :tax_inheritance_disabled,
  :rule,
  :last_modified)
  SENSITIVE = []
  include Aws::Structure
end

#ruleTypes::InvoiceUnitRule

An ‘InvoiceUnitRule` object used the categorize invoice units.



1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-invoicing/types.rb', line 1076

class InvoiceUnit < Struct.new(
  :invoice_unit_arn,
  :invoice_receiver,
  :name,
  :description,
  :tax_inheritance_disabled,
  :rule,
  :last_modified)
  SENSITIVE = []
  include Aws::Structure
end

#tax_inheritance_disabledBoolean

Whether the invoice unit based tax inheritance is/ should be enabled or disabled.

Returns:

  • (Boolean)


1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/aws-sdk-invoicing/types.rb', line 1076

class InvoiceUnit < Struct.new(
  :invoice_unit_arn,
  :invoice_receiver,
  :name,
  :description,
  :tax_inheritance_disabled,
  :rule,
  :last_modified)
  SENSITIVE = []
  include Aws::Structure
end