Class: Aws::Invoicing::Types::ProcurementPortalPreference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-invoicing/types.rb

Overview

Represents the full configuration of a procurement portal preference, including settings for e-invoice delivery and purchase order retrieval.

Constant Summary collapse

SENSITIVE =
[:contacts]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID associated with this procurement portal preference.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#buyer_domainString

The domain identifier for the buyer in the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#buyer_identifierString

The unique identifier for the buyer in the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#contactsArray<Types::Contact>

List of contact information for portal administrators and technical contacts.

Returns:



1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#create_dateTime

The date and time when the procurement portal preference was created.

Returns:

  • (Time)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#einvoice_delivery_enabledBoolean

Indicates whether e-invoice delivery is enabled for this procurement portal preference.

Returns:

  • (Boolean)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#einvoice_delivery_preferenceTypes::EinvoiceDeliveryPreference

The configuration settings that specify how e-invoices are delivered to the procurement portal.



1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#einvoice_delivery_preference_statusString

The current status of the e-invoice delivery preference.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#einvoice_delivery_preference_status_reasonString

The reason for the current e-invoice delivery preference status.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#last_update_dateTime

The date and time when the procurement portal preference was last updated.

Returns:

  • (Time)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#procurement_portal_instance_endpointString

The endpoint URL where e-invoices are delivered to the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#procurement_portal_nameString

The name of the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#procurement_portal_preference_arnString

The Amazon Resource Name (ARN) of the procurement portal preference.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#procurement_portal_shared_secretString

The shared secret or authentication credential used for secure communication with the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#purchase_order_retrieval_enabledBoolean

Indicates whether purchase order retrieval is enabled for this procurement portal preference.

Returns:

  • (Boolean)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#purchase_order_retrieval_endpointString

The endpoint URL used for retrieving purchase orders from the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#purchase_order_retrieval_preference_statusString

The current status of the purchase order retrieval preference.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#purchase_order_retrieval_preference_status_reasonString

The reason for the current purchase order retrieval preference status.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#selectorTypes::ProcurementPortalPreferenceSelector

Specifies criteria for selecting which invoices should be processed using a particular procurement portal preference.



1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#supplier_domainString

The domain identifier for the supplier in the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#supplier_identifierString

The unique identifier for the supplier in the procurement portal.

Returns:

  • (String)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#test_env_preferenceTypes::TestEnvPreference

Configuration on settings for the test environment of the procurement portal.



1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end

#versionInteger

The version number of the procurement portal preference configuration.

Returns:

  • (Integer)


1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'lib/aws-sdk-invoicing/types.rb', line 1419

class ProcurementPortalPreference < Struct.new(
  :aws_account_id,
  :procurement_portal_preference_arn,
  :procurement_portal_name,
  :buyer_domain,
  :buyer_identifier,
  :supplier_domain,
  :supplier_identifier,
  :selector,
  :procurement_portal_shared_secret,
  :procurement_portal_instance_endpoint,
  :purchase_order_retrieval_endpoint,
  :test_env_preference,
  :einvoice_delivery_enabled,
  :einvoice_delivery_preference,
  :purchase_order_retrieval_enabled,
  :contacts,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :version,
  :create_date,
  :last_update_date)
  SENSITIVE = [:contacts]
  include Aws::Structure
end