Class: Aws::Invoicing::Types::PutProcurementPortalPreferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::PutProcurementPortalPreferenceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:procurement_portal_shared_secret, :contacts]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
-
#contacts ⇒ Array<Types::Contact>
Updated list of contact information for portal administrators and technical contacts.
-
#einvoice_delivery_enabled ⇒ Boolean
Updated flag indicating whether e-invoice delivery is enabled for this procurement portal preference.
-
#einvoice_delivery_preference ⇒ Types::EinvoiceDeliveryPreference
Updated e-invoice delivery configuration including document types, attachment types, and customization settings for the portal.
-
#procurement_portal_instance_endpoint ⇒ String
The updated endpoint URL where e-invoices will be delivered to the procurement portal.
-
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to update.
-
#procurement_portal_shared_secret ⇒ String
The updated shared secret or authentication credential for the procurement portal.
-
#purchase_order_retrieval_enabled ⇒ Boolean
Updated flag indicating whether purchase order retrieval is enabled for this procurement portal preference.
-
#selector ⇒ Types::ProcurementPortalPreferenceSelector
Specifies criteria for selecting which invoices should be processed using a particular procurement portal preference.
-
#test_env_preference ⇒ Types::TestEnvPreferenceInput
Updated configuration settings for the test environment of the procurement portal.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#contacts ⇒ Array<Types::Contact>
Updated list of contact information for portal administrators and technical contacts.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#einvoice_delivery_enabled ⇒ Boolean
Updated flag indicating whether e-invoice delivery is enabled for this procurement portal preference.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#einvoice_delivery_preference ⇒ Types::EinvoiceDeliveryPreference
Updated e-invoice delivery configuration including document types, attachment types, and customization settings for the portal.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#procurement_portal_instance_endpoint ⇒ String
The updated endpoint URL where e-invoices will be delivered to the procurement portal. Must be a valid HTTPS URL.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to update.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#procurement_portal_shared_secret ⇒ String
The updated shared secret or authentication credential for the procurement portal. This value must be encrypted at rest.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#purchase_order_retrieval_enabled ⇒ Boolean
Updated flag indicating whether purchase order retrieval is enabled for this procurement portal preference.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#selector ⇒ Types::ProcurementPortalPreferenceSelector
Specifies criteria for selecting which invoices should be processed using a particular procurement portal preference.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |
#test_env_preference ⇒ Types::TestEnvPreferenceInput
Updated configuration settings for the test environment of the procurement portal.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1648 class PutProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :client_token) SENSITIVE = [:procurement_portal_shared_secret, :contacts] include Aws::Structure end |