Class: Aws::Invoicing::Types::SendProcurementPortalValidationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-invoicing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1782
1783
1784
1785
1786
1787
# File 'lib/aws-sdk-invoicing/types.rb', line 1782

class SendProcurementPortalValidationRequest < Struct.new(
  :procurement_portal_preference_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#procurement_portal_preference_arnString

The Amazon Resource Name (ARN) of the procurement portal preference to validate.

Returns:

  • (String)


1782
1783
1784
1785
1786
1787
# File 'lib/aws-sdk-invoicing/types.rb', line 1782

class SendProcurementPortalValidationRequest < Struct.new(
  :procurement_portal_preference_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end