Class: Aws::Invoicing::Types::UpdateProcurementPortalPreferenceStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-invoicing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/aws-sdk-invoicing/types.rb', line 2125

class UpdateProcurementPortalPreferenceStatusRequest < Struct.new(
  :procurement_portal_preference_arn,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#einvoice_delivery_preference_statusString

The updated status of the e-invoice delivery preference.

Returns:

  • (String)


2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/aws-sdk-invoicing/types.rb', line 2125

class UpdateProcurementPortalPreferenceStatusRequest < Struct.new(
  :procurement_portal_preference_arn,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#einvoice_delivery_preference_status_reasonString

The reason for the e-invoice delivery preference status update, providing context for the change.

Returns:

  • (String)


2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/aws-sdk-invoicing/types.rb', line 2125

class UpdateProcurementPortalPreferenceStatusRequest < Struct.new(
  :procurement_portal_preference_arn,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#procurement_portal_preference_arnString

The Amazon Resource Name (ARN) of the procurement portal preference to update.

Returns:

  • (String)


2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/aws-sdk-invoicing/types.rb', line 2125

class UpdateProcurementPortalPreferenceStatusRequest < Struct.new(
  :procurement_portal_preference_arn,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#purchase_order_retrieval_preference_statusString

The updated status of the purchase order retrieval preference.

Returns:

  • (String)


2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/aws-sdk-invoicing/types.rb', line 2125

class UpdateProcurementPortalPreferenceStatusRequest < Struct.new(
  :procurement_portal_preference_arn,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#purchase_order_retrieval_preference_status_reasonString

The reason for the purchase order retrieval preference status update, providing context for the change.

Returns:

  • (String)


2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/aws-sdk-invoicing/types.rb', line 2125

class UpdateProcurementPortalPreferenceStatusRequest < Struct.new(
  :procurement_portal_preference_arn,
  :einvoice_delivery_preference_status,
  :einvoice_delivery_preference_status_reason,
  :purchase_order_retrieval_preference_status,
  :purchase_order_retrieval_preference_status_reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end