Class: Aws::Invoicing::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
The input fails to satisfy the constraints specified by an Amazon Web Services service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_list ⇒ Array<Types::ValidationExceptionField>
The input fails to satisfy the constraints specified by an Amazon Web Services service.
- #message ⇒ String
-
#reason ⇒ String
You don’t have sufficient access to perform this action.
-
#resource_name ⇒ String
You don’t have sufficient access to perform this action.
Instance Attribute Details
#field_list ⇒ Array<Types::ValidationExceptionField>
The input fails to satisfy the constraints specified by an Amazon Web Services service.
2083 2084 2085 2086 2087 2088 2089 2090 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2083 class ValidationException < Struct.new( :message, :resource_name, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
2083 2084 2085 2086 2087 2088 2089 2090 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2083 class ValidationException < Struct.new( :message, :resource_name, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
You don’t have sufficient access to perform this action.
2083 2084 2085 2086 2087 2088 2089 2090 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2083 class ValidationException < Struct.new( :message, :resource_name, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
You don’t have sufficient access to perform this action.
2083 2084 2085 2086 2087 2088 2089 2090 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2083 class ValidationException < Struct.new( :message, :resource_name, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |