Class: Aws::Invoicing::Types::DeleteProcurementPortalPreferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::DeleteProcurementPortalPreferenceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
-
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to delete.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
428 429 430 431 432 433 |
# File 'lib/aws-sdk-invoicing/types.rb', line 428 class DeleteProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to delete.
428 429 430 431 432 433 |
# File 'lib/aws-sdk-invoicing/types.rb', line 428 class DeleteProcurementPortalPreferenceRequest < Struct.new( :procurement_portal_preference_arn, :client_token) SENSITIVE = [] include Aws::Structure end |