Class: Aws::Invoicing::Types::InvoiceUnitRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::InvoiceUnitRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
This is used to categorize the invoice unit. Values are Amazon Web Services account IDs. Currently, the only supported rule is ‘LINKED_ACCOUNT`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bill_source_accounts ⇒ Array<String>
A list of Amazon Web Services account IDs that have delegated their billing responsibility to the receiver account through transfer billing.
-
#linked_accounts ⇒ Array<String>
The list of ‘LINKED_ACCOUNT` IDs where charges are included within the invoice unit.
Instance Attribute Details
#bill_source_accounts ⇒ Array<String>
A list of Amazon Web Services account IDs that have delegated their billing responsibility to the receiver account through transfer billing. Unlike linked accounts, these bill source accounts can be payer accounts from other organizations that have authorized billing transfer to this account.
1107 1108 1109 1110 1111 1112 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1107 class InvoiceUnitRule < Struct.new( :linked_accounts, :bill_source_accounts) SENSITIVE = [] include Aws::Structure end |
#linked_accounts ⇒ Array<String>
The list of ‘LINKED_ACCOUNT` IDs where charges are included within the invoice unit.
1107 1108 1109 1110 1111 1112 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1107 class InvoiceUnitRule < Struct.new( :linked_accounts, :bill_source_accounts) SENSITIVE = [] include Aws::Structure end |