Class: Aws::Invoicing::Types::ProcurementPortalPreference
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::ProcurementPortalPreference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Represents the full configuration of a procurement portal preference, including settings for e-invoice delivery and purchase order retrieval.
Constant Summary collapse
- SENSITIVE =
[:contacts]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID associated with this procurement portal preference.
-
#buyer_domain ⇒ String
The domain identifier for the buyer in the procurement portal.
-
#buyer_identifier ⇒ String
The unique identifier for the buyer in the procurement portal.
-
#contacts ⇒ Array<Types::Contact>
List of contact information for portal administrators and technical contacts.
-
#create_date ⇒ Time
The date and time when the procurement portal preference was created.
-
#einvoice_delivery_enabled ⇒ Boolean
Indicates whether e-invoice delivery is enabled for this procurement portal preference.
-
#einvoice_delivery_preference ⇒ Types::EinvoiceDeliveryPreference
The configuration settings that specify how e-invoices are delivered to the procurement portal.
-
#einvoice_delivery_preference_status ⇒ String
The current status of the e-invoice delivery preference.
-
#einvoice_delivery_preference_status_reason ⇒ String
The reason for the current e-invoice delivery preference status.
-
#last_update_date ⇒ Time
The date and time when the procurement portal preference was last updated.
-
#procurement_portal_instance_endpoint ⇒ String
The endpoint URL where e-invoices are delivered to the procurement portal.
-
#procurement_portal_name ⇒ String
The name of the procurement portal.
-
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference.
-
#procurement_portal_shared_secret ⇒ String
The shared secret or authentication credential used for secure communication with the procurement portal.
-
#purchase_order_retrieval_enabled ⇒ Boolean
Indicates whether purchase order retrieval is enabled for this procurement portal preference.
-
#purchase_order_retrieval_endpoint ⇒ String
The endpoint URL used for retrieving purchase orders from the procurement portal.
-
#purchase_order_retrieval_preference_status ⇒ String
The current status of the purchase order retrieval preference.
-
#purchase_order_retrieval_preference_status_reason ⇒ String
The reason for the current purchase order retrieval preference status.
-
#selector ⇒ Types::ProcurementPortalPreferenceSelector
Specifies criteria for selecting which invoices should be processed using a particular procurement portal preference.
-
#supplier_domain ⇒ String
The domain identifier for the supplier in the procurement portal.
-
#supplier_identifier ⇒ String
The unique identifier for the supplier in the procurement portal.
-
#test_env_preference ⇒ Types::TestEnvPreference
Configuration on settings for the test environment of the procurement portal.
-
#version ⇒ Integer
The version number of the procurement portal preference configuration.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID associated with this procurement portal preference.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#buyer_domain ⇒ String
The domain identifier for the buyer in the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#buyer_identifier ⇒ String
The unique identifier for the buyer in the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#contacts ⇒ Array<Types::Contact>
List of contact information for portal administrators and technical contacts.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#create_date ⇒ Time
The date and time when the procurement portal preference was created.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#einvoice_delivery_enabled ⇒ Boolean
Indicates whether e-invoice delivery is enabled for this procurement portal preference.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#einvoice_delivery_preference ⇒ Types::EinvoiceDeliveryPreference
The configuration settings that specify how e-invoices are delivered to the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#einvoice_delivery_preference_status ⇒ String
The current status of the e-invoice delivery preference.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#einvoice_delivery_preference_status_reason ⇒ String
The reason for the current e-invoice delivery preference status.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#last_update_date ⇒ Time
The date and time when the procurement portal preference was last updated.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#procurement_portal_instance_endpoint ⇒ String
The endpoint URL where e-invoices are delivered to the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#procurement_portal_name ⇒ String
The name of the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#procurement_portal_shared_secret ⇒ String
The shared secret or authentication credential used for secure communication with the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#purchase_order_retrieval_enabled ⇒ Boolean
Indicates whether purchase order retrieval is enabled for this procurement portal preference.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#purchase_order_retrieval_endpoint ⇒ String
The endpoint URL used for retrieving purchase orders from the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#purchase_order_retrieval_preference_status ⇒ String
The current status of the purchase order retrieval preference.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#purchase_order_retrieval_preference_status_reason ⇒ String
The reason for the current purchase order retrieval preference status.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#selector ⇒ Types::ProcurementPortalPreferenceSelector
Specifies criteria for selecting which invoices should be processed using a particular procurement portal preference.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#supplier_domain ⇒ String
The domain identifier for the supplier in the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#supplier_identifier ⇒ String
The unique identifier for the supplier in the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#test_env_preference ⇒ Types::TestEnvPreference
Configuration on settings for the test environment of the procurement portal.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |
#version ⇒ Integer
The version number of the procurement portal preference configuration.
1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/aws-sdk-invoicing/types.rb', line 1394 class ProcurementPortalPreference < Struct.new( :aws_account_id, :procurement_portal_preference_arn, :procurement_portal_name, :buyer_domain, :buyer_identifier, :supplier_domain, :supplier_identifier, :selector, :procurement_portal_shared_secret, :procurement_portal_instance_endpoint, :purchase_order_retrieval_endpoint, :test_env_preference, :einvoice_delivery_enabled, :einvoice_delivery_preference, :purchase_order_retrieval_enabled, :contacts, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :version, :create_date, :last_update_date) SENSITIVE = [:contacts] include Aws::Structure end |