Class: Aws::Invoicing::Types::UpdateProcurementPortalPreferenceStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::UpdateProcurementPortalPreferenceStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
-
#einvoice_delivery_preference_status ⇒ String
The updated status of the e-invoice delivery preference.
-
#einvoice_delivery_preference_status_reason ⇒ String
The reason for the e-invoice delivery preference status update, providing context for the change.
-
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to update.
-
#purchase_order_retrieval_preference_status ⇒ String
The updated status of the purchase order retrieval preference.
-
#purchase_order_retrieval_preference_status_reason ⇒ String
The reason for the purchase order retrieval preference status update, providing context for the change.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2125 class UpdateProcurementPortalPreferenceStatusRequest < Struct.new( :procurement_portal_preference_arn, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#einvoice_delivery_preference_status ⇒ String
The updated status of the e-invoice delivery preference.
2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2125 class UpdateProcurementPortalPreferenceStatusRequest < Struct.new( :procurement_portal_preference_arn, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#einvoice_delivery_preference_status_reason ⇒ String
The reason for the e-invoice delivery preference status update, providing context for the change.
2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2125 class UpdateProcurementPortalPreferenceStatusRequest < Struct.new( :procurement_portal_preference_arn, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to update.
2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2125 class UpdateProcurementPortalPreferenceStatusRequest < Struct.new( :procurement_portal_preference_arn, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#purchase_order_retrieval_preference_status ⇒ String
The updated status of the purchase order retrieval preference.
2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2125 class UpdateProcurementPortalPreferenceStatusRequest < Struct.new( :procurement_portal_preference_arn, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#purchase_order_retrieval_preference_status_reason ⇒ String
The reason for the purchase order retrieval preference status update, providing context for the change.
2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2125 class UpdateProcurementPortalPreferenceStatusRequest < Struct.new( :procurement_portal_preference_arn, :einvoice_delivery_preference_status, :einvoice_delivery_preference_status_reason, :purchase_order_retrieval_preference_status, :purchase_order_retrieval_preference_status_reason, :client_token) SENSITIVE = [] include Aws::Structure end |