Class: Aws::Invoicing::Types::VerifyProcurementPortalValidationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Invoicing::Types::VerifyProcurementPortalValidationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-invoicing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
-
#code ⇒ String
The validation code received from the procurement portal in response to a previous
SendProcurementPortalValidationrequest. -
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to validate.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
2221 2222 2223 2224 2225 2226 2227 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2221 class VerifyProcurementPortalValidationRequest < Struct.new( :procurement_portal_preference_arn, :code, :client_token) SENSITIVE = [] include Aws::Structure end |
#code ⇒ String
The validation code received from the procurement portal in response
to a previous SendProcurementPortalValidation request.
2221 2222 2223 2224 2225 2226 2227 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2221 class VerifyProcurementPortalValidationRequest < Struct.new( :procurement_portal_preference_arn, :code, :client_token) SENSITIVE = [] include Aws::Structure end |
#procurement_portal_preference_arn ⇒ String
The Amazon Resource Name (ARN) of the procurement portal preference to validate.
2221 2222 2223 2224 2225 2226 2227 |
# File 'lib/aws-sdk-invoicing/types.rb', line 2221 class VerifyProcurementPortalValidationRequest < Struct.new( :procurement_portal_preference_arn, :code, :client_token) SENSITIVE = [] include Aws::Structure end |